@@ -370,8 +370,11 @@ impl Error {
     }
 
     #[allow(clippy::must_use_candidate)]
-    pub fn newc(kind: ErrorKind, message: Option<String>) -> Self {
-        Self { kind, message }
+    pub fn newc(kind: ErrorKind, message: Option<impl fmt::Display>) -> Self {
+        Self {
+            kind,
+            message: message.map(|v| v.to_string()),
+        }
     }
 
     pub fn code(&self) -> i16 {
